@@ -1,6 +1,6 @@
 package DNS::Oterica::Hub;
-BEGIN {
-  $DNS::Oterica::Hub::VERSION = '0.100001';
+{
+  $DNS::Oterica::Hub::VERSION = '0.200';
 }
 # ABSTRACT: the center of control for a DNS::Oterica system
 
@@ -9,14 +9,14 @@ with 'DNS::Oterica::Role::RecordMaker';
 
 # use MooseX::AttributeHelpers;
 
-use DNS::Oterica::Location;
+use DNS::Oterica::Network;
 use DNS::Oterica::Node;
 use DNS::Oterica::Node::Domain;
 use DNS::Oterica::Node::Host;
 use DNS::Oterica::NodeFamily;
 
 
-has [ qw(_domain_registry _loc_registry _node_family_registry) ] => (
+has [ qw(_domain_registry _net_registry _node_family_registry) ] => (
   is  => 'ro',
   isa => 'HashRef',
   init_arg => undef,
@@ -48,6 +48,9 @@ use Module::Pluggable
   search_path => [ qw(DNS::Oterica::NodeFamily) ],
   require     => 1;
 
+has fallback_network_name => (is => 'ro', isa => 'Str', default => 'FALLBACK');
+has all_network_name   => (is => 'ro', isa => 'Str', default => 'ALL');
+
 sub BUILD {
   my ($self) = @_;
 
@@ -58,9 +61,16 @@ sub BUILD {
         = $plugin->new({ hub => $self });
   }
 
-  $self->_loc_registry->{world} = DNS::Oterica::Location->new({
-    name => 'world',
+  $self->add_network({
+    name => $self->fallback_network_name,
+    code => 'FB', # should it be configurable?  eh.
+    subnet => '0.0.0.0/0',
+  });
+
+  $self->add_network({
+    name => $self->all_network_name,
     code => '',
+    subnet => '0.0.0.0/32',
   });
 }
 
@@ -82,20 +92,49 @@ sub domain {
 }
 
 
-sub location {
+sub network {
   my ($self, $name) = @_;
-  return $self->_loc_registry->{$name} || confess "no such location '$name'";
+  return $self->_net_registry->{$name} || confess "no such network '$name'";
 }
 
 
-sub add_location {
+sub networks {
+  my ($self) = @_;
+  return values %{ $self->_net_registry };
+}
+
+
+sub add_network {
   my ($self, $arg) = @_;
-  my $loc = DNS::Oterica::Location->new({ %$arg, hub => $self });
 
-  my $name = $loc->name;
-  confess "tried to create $name twice" if $self->_loc_registry->{$name};
+  my $net = DNS::Oterica::Network->new({ %$arg, hub => $self });
 
-  $self->_loc_registry->{$name} = $loc;
+  my $name = $net->name;
+  confess "tried to create $name twice" if $self->_net_registry->{$name};
+
+  my $code = $net->code;
+  my $ip   = $net->subnet;
+
+  my @errors;
+  for my $existing ($self->networks) {
+    if ($net->code eq $existing->code) {
+      push @errors, sprintf "code '%s' conflicts with network %s",
+        $code, $existing->name;
+    }
+
+    next if $existing->name eq $self->all_network_name;
+
+    if ($ip->overlaps($existing->subnet) == $Net::IP::IP_IDENTICAL) {
+      push @errors, sprintf "network '%s' conflicts with network %s (%s)",
+        $ip->ip, $existing->name, $existing->subnet->ip;
+    }
+  }
+
+  if (@errors) {
+    confess("errors registering network $name: " . join q{; }, @errors);
+  }
+
+  $self->_net_registry->{$name} = $net;
 }
 
 
@@ -146,6 +185,7 @@ no Moose;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -154,7 +194,7 @@ DNS::Oterica::Hub - the center of control for a DNS::Oterica system
 
 =head1 VERSION
 
-version 0.100001
+version 0.200
 
 =head1 OVERVIEW
 
@@ -188,18 +228,22 @@ If no domain is found and C<\%arg> is not given, an exception is raised.
 
 If C<\%arg> is given for a domain that already exists, an exception is raised.
 
-=head2 location
+=head2 network
 
-  my $loc = $hub->location($name);
+  my $net = $hub->network($name);
 
-This method finds the named location and returns it.  If no location for the
+This method finds the named network and returns it.  If no network for the
 given name is registered, an exception is raised.
 
-=head2 add_location
+=head2 networks
 
-  my $loc = $hub->add_location(\%arg);
+  my @net = $hub->networks;
 
-This registers a new location, raising an exception if one already exists for
+=head2 add_network
+
+  my $net = $hub->add_network(\%arg);
+
+This registers a new network, raising an exception if one already exists for
 the given name.
 
 =head2 host
@@ -236,10 +280,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
