@@ -1,6 +1,6 @@
 package DNS::Oterica::NodeFamily;
-BEGIN {
-  $DNS::Oterica::NodeFamily::VERSION = '0.100001';
+{
+  $DNS::Oterica::NodeFamily::VERSION = '0.200';
 }
 # ABSTRACT: a group of hosts that share common functions
 use Moose;
@@ -38,21 +38,14 @@ sub as_data_lines {
   return @lines;
 }
 
-
-has hub => (
-  is   => 'ro',
-  isa  => 'DNS::Oterica::Hub',
-  weak_ref => 1,
-  required => 1,
-  # handles  => 'DNS::Oterica::Role::RecordMaker',
-  handles  => [ qw(rec) ],
-);
+with 'DNS::Oterica::Role::HasHub';
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -61,7 +54,7 @@ DNS::Oterica::NodeFamily - a group of hosts that share common functions
 
 =head1 VERSION
 
-version 0.100001
+version 0.200
 
 =head1 ATTRIBUTES
 
@@ -69,10 +62,6 @@ version 0.100001
 
 This is an arrayref of the node objects that are in this family.
 
-=head2 hub
-
-This is the hub object into which the family was registered.
-
 =head1 METHODS
 
 =head2 add_node
@@ -93,10 +82,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
